measuretools.extend_measures_in_expr_and_apply_full_measure_tuplets
===================================================================

.. autofunction:: abjad.tools.measuretools.extend_measures_in_expr_and_apply_full_measure_tuplets.extend_measures_in_expr_and_apply_full_measure_tuplets
   :noindex:
